This package uses the following libraries and might packaged with the following directly referenced as found in **requirements.txt**

* `troposphere`_ - `BSD-2 Clause License`_
* `boto3`_ - `Apache 2.0 License`_
* `requests`_ - `Apache 2.0 License`_
* `aws-sam-translator`_ - `Apache 2.0 License`_

License files can be found here

* `Apache 2.0 License`_
* `BSD-2 Clause License`_

.. _troposphere: https://pypi.org/project/troposphere/
.. _boto3: https://pypi.org/project/boto3/
.. _requests: https://pypi.org/project/requests/
.. _aws-sam-translator: https://pypi.org/project/aws-sam-translator

.. _Apache 2.0 License: https://www.apache.org/licenses/LICENSE-2.0.txt
.. _BSD-2 Clause License: https://opensource.org/licenses/BSD-2-Clause
